=======
Credits
=======

.. include:: ../AUTHORS.rst

Used Libraries
--------------
Primap2 is built on lots of very useful libraries:
 - The package structure was created with
   `Cookiecutter <https://github.com/audreyr/cookiecutter>`_ and the
   `audreyr/cookiecutter-pypackage <https://github.com/audreyr/cookiecutter-pypackage>`_
   project template.
